Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DiskStats ¶
type DiskStats struct {
MountPath string
DiskSpaceAvailable uint64
DiskSpaceUsed uint64
DiskSpaceUtilization float64
}
DiskStats represents a snapshot of disk statistics for a path at a given point in time
func GetDiskStats ¶
GetDiskStats retrieves disk statistics for the specified path
type MemoryStats ¶
type MemoryStats struct {
MemoryAvailable uint64
MemoryUsed uint64
MemoryUtilization float64
SwapAvailable uint64
SwapUsed uint64
SwapUtilization float64
}
MemoryStats represents snapshot of memory statistics at a given point in time
func GetMemoryStats ¶
func GetMemoryStats() (*MemoryStats, error)
GetMemoryStats returns memory and swap statistics
Click to show internal directories.
Click to hide internal directories.